#!/bin/bash

# SLURM configuration for MN5
# information about the queue : https://www.bsc.es/supportkc/docs/MareNostrum5/slurm

# HOW to SUBMIT 
# sbatch -A, --account={account} -q, --qos={qos} {job_script} [args]

# Single job with a single node (default)
##BATCH --qos=gp_debug
##SBATCH --qos=acc_debug
#SBATCH --qos=gp_bsces
#SBATCH --output=serial_%j.out
#SBATCH --error=serial_%j.err
##SBATCH --ntasks=112
#SBATCH --ntasks=1420
#SBATCH --time=02:00:00
#SBATCH --mail-type=end
#SBATCH --mail-user=amirpasha.mozaffari@bsc.es

# SLURM configuration for NORD3
# more information here : https://earth.bsc.es/wiki/doku.php?id=computing:nord3-v2

# HOW to SUBMIT 
# sbatch -A, --account={account} -q, --qos={qos} {job_script} [args]
# sbatch -A bsc32 -q bsc_es launch_remap_NR3.sh

# Single job with a single node (default)
##SBATCH --qos=bsc_es
##SBATCH --output=serial_%j.out
##SBATCH --error=serial_%j.err
##SBATCH --ntasks=10
##SBATCH --time=00:30:00
##SBATCH --mail-type=end
##SBATCH --mail-user=amirpasha.mozaffari@bsc.es
##SBATCH --constraint=highmem
##SBATCH --exclusive

# Load appropriate modules and activate conda environment
if [ "$BSC_MACHINE" = "mn5" ]; then

    export MODULEPATH=$MODULEPATH:/apps/GPP/EASYBUILD/modules/all
    # module load GDAL/3.8.5-foss-2023b
    # module load NCO/5.2.4-foss-2023b
    # module load miniconda
    # module load hdf5/1.14.1-2
    # module load pnetcdf/1.12.3
    # module load netcdf/2023-06-14
    # module load miniconda
    conda init
    source /apps/GPP/MINICONDA/24.1.2/etc/profile.d/conda.sh
    conda activate /gpfs/projects/bsc32/repository/apps/conda_envs/LAND_may2024_v1
    export PYTHONPATH=/gpfs/projects/bsc32/repository/apps/conda_envs/LAND_may2024_v1/lib/python3.12/site-packages:$PYTHONPATH

elif [ "$BSC_MACHINE" = "nord3v2" ]; then
    module load GDAL/3.3.2-foss-2019b-Python-3.7.4
    module load pycdo/1.5.3-foss-2019b-Python-3.7.4
    module load pynco/0.0.2-foss-2019b-Python-3.7.4
fi

# Launch training script 
# Set parameters
SAVE_DATA_PATH="/gpfs/projects/bsc32/cerise/outputs/bsc032013/ml/ES/"
DEFAULT_DATA_PATH="/gpfs/projects/bsc32/cerise/outputs/bsc032013/0.0089_deg/"
REGIONS_FILE_PATH="/gpfs/scratch/bsc32/bsc032013/cerise/land-use-reclassification/ml/LC/inputs/ES_regions.json"
DB_PATH="/gpfs/projects/bsc32/cerise/outputs/bsc032013/ml/lc/db/xgb_v1.db"
START_YEAR=1925
END_YEAR=1991
TRAINING_START_YEAR="1992"
TRAINING_END_YEAR="2015"

# List of regions to loop over
REGIONS=("ES1" "ES2" "ES3" "ES4" "ES5" "ES6")

# Loop over each region
for REGION in "${REGIONS[@]}"
do
    echo "Processing region: $REGION"
    
    # Run the Python script for each region with all parameters
    python inference_preprocessing_XGB.py --save_data_path $SAVE_DATA_PATH \
                                          --default_data_path $DEFAULT_DATA_PATH \
                                          --regions_file $REGIONS_FILE_PATH \
                                          --db_path $DB_PATH \
                                          --start_year $START_YEAR \
                                          --end_year $END_YEAR \
                                          --train_start_year $TRAINING_START_YEAR \
                                          --train_end_year $TRAINING_END_YEAR \
                                          --region $REGION \
                                          --include_luh2 \
                                          --include_hilda \
                                          --dtype_luh2 float32 \
                                          --dtype_hilda float32 \
                                          --inspection \
                                          --read_db

done

# REGION="CAT"  # ES, EU, UK, AU, GLOBE, NW, NE, SW, SE 
# Run the Python script with arguments
#python inference_preprocessing.py --start_year $START_YEAR --end_year $END_YEAR --train_start_year $TRAINING_START_YEAR --train_end_year $TRAINING_END_YEAR --region $REGION  --include_luh2 --include_hilda  --dtype_luh2 float32  --dtype_hilda float32
#python inference_preprocessing_XGB.py --save_data_path $Save_data_path --default_data_path $Default_data_path --start_year $START_YEAR --end_year $END_YEAR --train_start_year $TRAINING_START_YEAR --train_end_year $TRAINING_END_YEAR --region $REGION  --include_luh2 --include_hilda  --dtype_luh2 float32  --dtype_hilda float32 --inspection
