#!/bin/bash

# SLURM configuration for MN5
# information about the queue : https://www.bsc.es/supportkc/docs/MareNostrum5/slurm

# HOW to SUBMIT 
# sbatch -A, --account={account} -q, --qos={qos} {job_script} [args]

# Single job with a single node (default)
##SBATCH --qos=gp_debug
#SBATCH --qos=acc_debug
##SBATCH --qos=acc_bsces
##SBATCH --qos=gp_bsces
#SBATCH --output=serial_%j.out
#SBATCH --error=serial_%j.err
##SBATCH --ntasks=112
#SBATCH --ntasks=640
#SBATCH --time=00:10:00
#SBATCH --mail-type=end
#SBATCH --mail-user=amirpasha.mozaffari@bsc.es

# SLURM configuration for NORD3
# more information here : https://earth.bsc.es/wiki/doku.php?id=computing:nord3-v2

# HOW to SUBMIT 
# sbatch -A, --account={account} -q, --qos={qos} {job_script} [args]
# sbatch -A bsc32 -q bsc_es launch_remap_NR3.sh

# Single job with a single node (default)
##SBATCH --qos=bsc_es
##SBATCH --output=serial_%j.out
##SBATCH --error=serial_%j.err
##SBATCH --ntasks=10
##SBATCH --time=00:30:00
##SBATCH --mail-type=end
##SBATCH --mail-user=amirpasha.mozaffari@bsc.es
##SBATCH --constraint=highmem
##SBATCH --exclusive

# Load appropriate modules and activate conda environment
if [ "$BSC_MACHINE" = "mn5" ]; then

    export MODULEPATH=$MODULEPATH:/apps/GPP/EASYBUILD/modules/all
    # module load GDAL/3.8.5-foss-2023b
    # module load NCO/5.2.4-foss-2023b
    # module load miniconda
    # module load hdf5/1.14.1-2
    # module load pnetcdf/1.12.3
    # module load netcdf/2023-06-14
    # module load miniconda
    conda init
    source /apps/GPP/MINICONDA/24.1.2/etc/profile.d/conda.sh
    conda activate /home/bsc/bsc032013/.conda/envs/acc_gpu
    export PYTHONPATH=/home/bsc/bsc032013/.conda/envs/acc_gpu/lib/python3.12/site-packages:$PYTHONPATH

elif [ "$BSC_MACHINE" = "nord3v2" ]; then
    module load GDAL/3.3.2-foss-2019b-Python-3.7.4
    module load pycdo/1.5.3-foss-2019b-Python-3.7.4
    module load pynco/0.0.2-foss-2019b-Python-3.7.4
fi

# Launch postprocessing script

# Set parameters
TRAIN_START_YEAR=1992
TRAIN_END_YEAR=2015
REGION="ES"
INFERENCE_YEARS=($(seq 1925 1991)) 
DATA_PATH="/gpfs/projects/bsc32/cerise/outputs/bsc032013/ml/ES/"
DB_PATH="/gpfs/projects/bsc32/cerise/outputs/bsc032013/ml/lc/db/xgb_v1.db"
# List of regions to loop over
REGIONS=("ES1" "ES2" "ES3" "ES4" "ES5" "ES6")

# Outer loop for regions
for REGION in "${REGIONS[@]}"
do
    echo "Processing region: $REGION"

    # Set the specific data path for each region
   # DATA_PATH="${DATA_PATH_BASE}/${REGION}"

    # Inner loop for each inference year
    for YEAR in "${INFERENCE_YEARS[@]}"
    do
        echo "Processing inference year: $YEAR for region: $REGION"
        
        # Run the Python script for each region and inference year with all parameters
        python inference_XGB_yearly.py --train_start_year $TRAIN_START_YEAR \
                                       --train_end_year $TRAIN_END_YEAR \
                                       --inference_years $YEAR \
                                       --region $REGION \
                                       --save_data_path $DATA_PATH \
                                       --db_path $DB_PATH \
                                       --use_db
    done
done

# MODEL_TIME_STAMP="20240929_214146"

# #python inference_scikit_yearly.py --train_start_year $TRAIN_START_YEAR --train_end_year $TRAIN_END_YEAR --inference_years $INFERENCE_YEARS --region $REGION --save_data_path $DATA_PATH --model_timestamp $MODEL_TIME_STAMP
# python inference_XGB_yearly.py --train_start_year $TRAIN_START_YEAR --train_end_year $TRAIN_END_YEAR --inference_years $INFERENCE_YEARS --region $REGION --save_data_path $DATA_PATH --model_timestamp $MODEL_TIME_STAMP
